Class: Retab::Partitions

Inherits:
Object
  • Object
show all
Defined in:
lib/retab/partitions.rb

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ Partitions

Returns a new instance of Partitions.



9
10
11
# File 'lib/retab/partitions.rb', line 9

def initialize(client)
  @client = client
end

Instance Method Details

#create(document:, key:, instructions:, model: nil, n_consensus: nil, allow_overlap: nil, bust_cache: nil, request_options: {}) ⇒ Retab::Partition

Create Partitions

Parameters:

  • document (Retab::MimeData, Pathname, IO, String, Hash)

    The document to partition

  • key (String)

    The key to partition the document by

  • instructions (String)

    Instructions describing how the document should be partitioned

  • model (String, nil) (defaults to: nil)

    The model to use for partitioning

  • n_consensus (Integer, nil) (defaults to: nil)

    Number of partitioning runs to use for consensus voting. Uses deterministic single-pass when set to 1.

  • allow_overlap (Boolean, nil) (defaults to: nil)

    If true, allow a page to appear in more than one partition chunk

  • bust_cache (Boolean, nil) (defaults to: nil)

    If true, skip the LLM cache and force a fresh completion

  • request_options (Hash) (defaults to: {})

    (see Retab::Types::RequestOptions)

Returns:



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/retab/partitions.rb', line 79

def create(
  document:,
  key:,
  instructions:,
  model: nil,
  n_consensus: nil,
  allow_overlap: nil,
  bust_cache: nil,
  request_options: {}
)
  document = Retab::MimeData.coerce(document) unless document.nil?
  body = {
    'document' => document,
    'key' => key,
    'instructions' => instructions,
    'model' => model,
    'n_consensus' => n_consensus,
    'allow_overlap' => allow_overlap,
    'bust_cache' => bust_cache
  }.compact
  response = @client.request(
    method: :post,
    path: '/v1/partitions',
    auth: true,
    body: body,
    request_options: request_options
  )
  result = Retab::Partition.new(response.body)
  result.last_response = Retab::Types::ApiResponse.new(http_status: response.code.to_i, http_headers: response.each_header.to_h, request_id: response["x-request-id"])
  result
end

#delete(partition_id:, request_options: {}) ⇒ void

This method returns an undefined value.

Delete Partition

Parameters:

  • partition_id (String)
  • request_options (Hash) (defaults to: {})

    (see Retab::Types::RequestOptions)



134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/retab/partitions.rb', line 134

def delete(
  partition_id:,
  request_options: {}
)
  response = @client.request(
    method: :delete,
    path: "/v1/partitions/#{Retab::Util.encode_path(partition_id)}",
    auth: true,
    request_options: request_options
  )
  nil
end

#get(partition_id:, request_options: {}) ⇒ Retab::Partition

Get Partition

Parameters:

  • partition_id (String)
  • request_options (Hash) (defaults to: {})

    (see Retab::Types::RequestOptions)

Returns:



115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/retab/partitions.rb', line 115

def get(
  partition_id:,
  request_options: {}
)
  response = @client.request(
    method: :get,
    path: "/v1/partitions/#{Retab::Util.encode_path(partition_id)}",
    auth: true,
    request_options: request_options
  )
  result = Retab::Partition.new(response.body)
  result.last_response = Retab::Types::ApiResponse.new(http_status: response.code.to_i, http_headers: response.each_header.to_h, request_id: response["x-request-id"])
  result
end

#list(before: nil, after: nil, limit: 10, order: 'desc', filename: nil, from_date: nil, to_date: nil, request_options: {}) ⇒ Retab::Types::ListStruct<Retab::Partition>

List Partitions

Parameters:

  • before (String, nil) (defaults to: nil)
  • after (String, nil) (defaults to: nil)
  • limit (Integer, nil) (defaults to: 10)
  • order (Retab::Types::PartitionsOrder, nil) (defaults to: 'desc')
  • filename (String, nil) (defaults to: nil)
  • from_date (String, nil) (defaults to: nil)
  • to_date (String, nil) (defaults to: nil)
  • request_options (Hash) (defaults to: {})

    (see Retab::Types::RequestOptions)

Returns:



23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/retab/partitions.rb', line 23

def list(
  before: nil,
  after: nil,
  limit: 10,
  order: 'desc',
  filename: nil,
  from_date: nil,
  to_date: nil,
  request_options: {}
)
  params = {
    'before' => before,
    'after' => after,
    'limit' => limit,
    'order' => order,
    'filename' => filename,
    'from_date' => from_date,
    'to_date' => to_date
  }.compact
  response = @client.request(
    method: :get,
    path: '/v1/partitions',
    auth: true,
    params: params,
    request_options: request_options
  )
  fetch_next = ->(cursor) {
    list(
      before: before,
      after: cursor,
      limit: limit,
      order: order,
      filename: filename,
      from_date: from_date,
      to_date: to_date,
      request_options: request_options
    )
  }
  Retab::Types::ListStruct.from_response(
    response,
    model: Retab::Partition,
    filters: { before: before, limit: limit, order: order, filename: filename, from_date: from_date, to_date: to_date },
    fetch_next: fetch_next
  )
end